@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wrap_sub);
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 our %SPEC;
 
@@ -232,6 +232,7 @@ sub handle_default_lang {
     push @m, @{$meta->{examples}} if $meta->{examples};
     push @m, $meta->{result} if $meta->{result};
     push @m, values %{$meta->{args}} if $meta->{args};
+    push @m, (grep {ref($_) eq 'HASH'} @{$meta->{tags}}) if $meta->{tags};
 
     my $i = 0;
     my ($value, $new);
@@ -391,7 +392,7 @@ sub handle_args_as {
     $self->{_args_token} = $tok;
 }
 
-sub handlemeta_args { {prio=>10, convert=>1} }
+sub handlemeta_args { {prio=>10, convert=>0} }
 sub handle_args {
     require Data::Sah;
 
@@ -433,7 +434,7 @@ sub handle_args {
 }
 
 # XXX not implemented yet
-sub handlemeta_result { {prio=>50, convert=>1} }
+sub handlemeta_result { {prio=>50, convert=>0} }
 sub handle_result {
     require Data::Sah;
 
@@ -699,7 +700,9 @@ _
             summary => 'Properties to convert to new value',
             description => <<'_',
 
-So far you can convert 'args_as' and 'result_naked'.
+Not all properties can be converted, but these are a partial list of those that
+can: v (usually do not need to be specified when converting from 1.0 to 1.1,
+will be done automatically), args_as, result_naked, default_lang.
 
 _
         },
@@ -764,7 +767,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -851,7 +854,9 @@ source code.
 
 Properties to convert to new value.
 
-So far you can convert 'argsB<as' and 'result>naked'.
+Not all properties can be converted, but these are a partial list of those that
+can: v (usually do not need to be specified when converting from 1.0 to 1.1,
+will be done automatically), argsB<as, result>naked, default_lang.
 
 =item * B<meta>* => I<hash>
 
